@@ -27,6 +27,7 @@
 #include <AkonadiCore/itemfetchjob.h>
 #include <QIcon>
 #include <kio/jobuidelegate.h>
+#include <kio_version.h>
 
 #include <QMenu>
 #include <QPointer>
@@ -61,7 +62,9 @@
 #include <MessageCore/AttachmentPropertiesDialog>
 #include <settings/messagecomposersettings.h>
 
+#include <KJob>
 #include <KMime/Content>
+
 #include <QFileDialog>
 
 using namespace MessageComposer;
@@ -211,7 +214,7 @@ void AttachmentControllerBase::Private::loadJobResult(KJob *job)
 void AttachmentControllerBase::Private::openSelectedAttachments()
 {
     Q_ASSERT(selectedParts.count() >= 1);
-    for (const AttachmentPart::Ptr &part : qAsConst(selectedParts)) {
+    for (const AttachmentPart::Ptr &part : std::as_const(selectedParts)) {
         q->openAttachment(part);
     }
 }
@@ -219,7 +222,7 @@ void AttachmentControllerBase::Private::openSelectedAttachments()
 void AttachmentControllerBase::Private::viewSelectedAttachments()
 {
     Q_ASSERT(selectedParts.count() >= 1);
-    for (const AttachmentPart::Ptr &part : qAsConst(selectedParts)) {
+    for (const AttachmentPart::Ptr &part : std::as_const(selectedParts)) {
         q->viewAttachment(part);
     }
 }
@@ -311,7 +314,7 @@ void AttachmentControllerBase::Private::editDone(MessageViewer::EditorWatcher *w
 void AttachmentControllerBase::Private::createOpenWithMenu(QMenu *topMenu, const AttachmentPart::Ptr &part)
 {
     const QString contentTypeStr = QString::fromLatin1(part->mimeType());
-    const KService::List offers = KFileItemActions::associatedApplications(QStringList() << contentTypeStr, QString());
+    const KService::List offers = KFileItemActions::associatedApplications(QStringList() << contentTypeStr);
     if (!offers.isEmpty()) {
         QMenu *menu = topMenu;
         auto actionGroup = new QActionGroup(menu);
@@ -667,7 +670,7 @@ void AttachmentControllerBase::slotOpenWithDialog()
 
 void AttachmentControllerBase::slotOpenWithAction(QAction *act)
 {
-    KService::Ptr app = act->data().value<KService::Ptr>();
+    auto app = act->data().value<KService::Ptr>();
     Q_ASSERT(d->selectedParts.count() == 1);
 
     openWith(app);
