@@ -66,7 +66,7 @@ void SearchCollectionIndexingWarning::setCollection(const Akonadi::Collection &c
         return;
     }
 
-    const auto *attr = collection.attribute<Akonadi::PersistentSearchAttribute>();
+    const auto attr = collection.attribute<Akonadi::PersistentSearchAttribute>();
     Akonadi::Collection::List cols;
     const QVector<qint64> queryCols = attr->queryCollections();
     cols.reserve(queryCols.count());
@@ -116,7 +116,7 @@ void SearchCollectionIndexingWarning::queryCollectionFetchFinished(KJob *job)
 void SearchCollectionIndexingWarning::queryIndexerStatus()
 {
     bool allFullyIndexed = true;
-    for (const Akonadi::Collection &col : qAsConst(mCollections)) {
+    for (const Akonadi::Collection &col : std::as_const(mCollections)) {
         if (col.hasAttribute<Akonadi::EntityHiddenAttribute>()) {
             continue;
         }
